package models

type CustomDialysisData struct {
	Date  string `json:"date"`
	Count int64  `json:"count"`
	Total int64  `json:"total"`
}

type QCPrescription struct {
	ID                        int64                     `gorm:"column:id" json:"id"`
	UserOrgId                 int64                     `gorm:"column:user_org_id" json:"user_org_id"`
	PatientId                 int64                     `gorm:"column:patient_id" json:"patient_id"`
	ModeId                    int64                     `gorm:"column:mode_id" json:"mode_id"`
	Status                    int64                     `gorm:"column:status" json:"status"`
	CreatedTime               int64                     `gorm:"column:created_time" json:"created_time"`
	UpdatedTime               int64                     `gorm:"column:updated_time" json:"updated_time"`
	RecordDate                int64                     `gorm:"column:record_date" json:"record_date"`
	RecordId                  int64                     `gorm:"column:record_id" json:"record_id"`
	UserAdminRole             UserAdminRole             `json:"role" gorm:"foreignkey:AdminUserId;AssociationForeignKey:Creater;"`
	Creater                   int64                     `gorm:"column:creater" json:"creater"`
	Modifier                  int64                     `gorm:"column:modifier" json:"modifier"`
	QCPatients                QCPatients                `gorm:"ForeignKey:PatientId;AssociationForeignKey:ID" json:"patient"`
	QCDialysisOrder           QCDialysisOrder           `gorm:"ForeignKey:PatientId,DialysisDate;AssociationForeignKey:PatientId,RecordDate" json:"order"`
	QCAssessmentAfterDislysis QCAssessmentAfterDislysis `gorm:"ForeignKey:PatientId,AssessmentDate;AssociationForeignKey:PatientId,RecordDate" json:"ad"`
}

func (QCPrescription) TableName() string {
	return "xt_dialysis_prescription"
}

type QCPatients struct {
	ID         int64  `gorm:"column:id" json:"id" form:"id"`
	UserOrgId  int64  `gorm:"column:user_org_id" json:"user_org_id" form:"user_org_id"`
	Gender     int64  `gorm:"column:gender" json:"gender" form:"gender"`
	DialysisNo string `gorm:"column:dialysis_no" json:"dialysis_no" form:"dialysis_no"`
	Name       string `gorm:"column:name" json:"name" form:"name"`
	IdCardNo   string `gorm:"column:id_card_no" json:"id_card_no" form:"id_card_no"`
	Status     int64  `gorm:"column:status" json:"status" form:"status"`
}

func (QCPatients) TableName() string {
	return "xt_patients"
}

type QCDialysisOrder struct {
	ID             int64         `gorm:"column:id" json:"id"`
	DialysisDate   int64         `gorm:"column:dialysis_date" json:"dialysis_date"`
	UserOrgId      int64         `gorm:"column:user_org_id" json:"user_org_id"`
	PatientId      int64         `gorm:"column:patient_id" json:"patient_id"`
	Stage          int64         `gorm:"column:stage" json:"stage"`
	Remark         string        `gorm:"column:remark" json:"remark"`
	BedID          int64         `gorm:"column:bed_id" json:"bed_id"`
	StartNurse     int64         `gorm:"column:start_nurse" json:"start_nurse"`
	FinishNurse    int64         `gorm:"column:finish_nurse" json:"finish_nurse"`
	Status         int64         `gorm:"column:status" json:"status"`
	DeviceNumber   DeviceNumber  `gorm:"ForeignKey:BedID"`
	StartTime      int64         `gorm:"column:start_time" json:"start_time"`
	EndTime        int64         `gorm:"column:end_time" json:"end_time"`
	FinishCreator  int64         `gorm:"column:finish_creator" json:"finish_creator"`
	FinishModifier int64         `gorm:"column:finish_modifier" json:"finish_modifier"`
	SchedualType   int64         `gorm:"column:schedual_type" json:"schedual_type"`
	UserAdminRole  UserAdminRole `json:"role" gorm:"foreignkey:AdminUserId;AssociationForeignKey:StartNurse;"`
	ZoneId         int64         `gorm:"column:zone_id" json:"zone_id" form:"zone_id"`
}

func (QCDialysisOrder) TableName() string {
	return "xt_dialysis_order"
}

type QCAssessmentAfterDislysis struct {
	ID                    int64 `gorm:"column:id" json:"id" form:"id"`
	UserOrgId             int64 `gorm:"column:user_org_id" json:"user_org_id" form:"user_org_id"`
	PatientId             int64 `gorm:"column:patient_id" json:"patient_id" form:"patient_id"`
	AssessmentDate        int64 `gorm:"column:assessment_date" json:"assessment_date" form:"assessment_date"`
	ActualTreatmentHour   int64 `gorm:"column:actual_treatment_hour" json:"actual_treatment_hour" form:"actual_treatment_hour"`
	ActualTreatmentMinute int64 `gorm:"column:actual_treatment_minute" json:"actual_treatment_minute" form:"actual_treatment_minute"`
}

func (QCAssessmentAfterDislysis) TableName() string {

	return "xt_assessment_after_dislysis"
}

type QCSchedule struct {
	ID                        int64                     `gorm:"column:id" json:"id" form:"id"`
	UserOrgId                 int64                     `gorm:"column:user_org_id" json:"user_org_id" form:"user_org_id"`
	PatientId                 int64                     `gorm:"column:patient_id" json:"patient_id" form:"patient_id"`
	ScheduleDate              int64                     `gorm:"column:schedule_date" json:"schedule_date" form:"schedule_date"`
	ScheduleType              int64                     `gorm:"column:schedule_type" json:"schedule_type" form:"schedule_type"`
	ScheduleWeek              int64                     `gorm:"column:schedule_week" json:"schedule_week" form:"schedule_week"`
	ModeId                    int64                     `gorm:"column:mode_id" json:"mode_id" form:"mode_id"`
	Status                    int64                     `gorm:"column:status" json:"status" form:"status"`
	CreatedTime               int64                     `gorm:"column:created_time" json:"created_time" form:"created_time"`
	UpdatedTime               int64                     `gorm:"column:updated_time" json:"updated_time" form:"updated_time"`
	QCSPrescription           QCSPrescription           `gorm:"ForeignKey:RecordDate,PatientId;AssociationForeignKey:ScheduleDate,PatientId" json:"prescription"`
	QCPatients                QCPatients                `gorm:"ForeignKey:ID;AssociationForeignKey:PatientId" json:"patient"`
	QCDialysisOrder           QCDialysisOrder           `gorm:"ForeignKey:PatientId,DialysisDate;AssociationForeignKey:PatientId,ScheduleDate" json:"order"`
	QCAssessmentAfterDislysis QCAssessmentAfterDislysis `gorm:"ForeignKey:PatientId,AssessmentDate;AssociationForeignKey:PatientId,ScheduleDate" json:"ad"`
}

// `gorm:"ForeignKey:DialysisDate,PatientId;AssociationForeignKey:ScheduleDate,PatientId" json:"dialysis_order"`
func (QCSchedule) TableName() string {
	return "xt_schedule"
}

type QCSPrescription struct {
	ID            int64         `gorm:"column:id" json:"id"`
	UserOrgId     int64         `gorm:"column:user_org_id" json:"user_org_id"`
	PatientId     int64         `gorm:"column:patient_id" json:"patient_id"`
	ModeId        int64         `gorm:"column:mode_id" json:"mode_id"`
	Status        int64         `gorm:"column:status" json:"status"`
	CreatedTime   int64         `gorm:"column:created_time" json:"created_time"`
	UpdatedTime   int64         `gorm:"column:updated_time" json:"updated_time"`
	RecordDate    int64         `gorm:"column:record_date" json:"record_date"`
	RecordId      int64         `gorm:"column:record_id" json:"record_id"`
	UserAdminRole UserAdminRole `json:"role" gorm:"foreignkey:AdminUserId;AssociationForeignKey:Creater;"`
	Creater       int64         `gorm:"column:creater" json:"creater"`
	Modifier      int64         `gorm:"column:modifier" json:"modifier"`
}

func (QCSPrescription) TableName() string {
	return "xt_dialysis_prescription"
}
